@@ -1,4 +1,5 @@
 decimal.align<-function(x,dechar=".",nint=NA,ndec=NA,pad.left=TRUE) {
+
  splitchar<-paste("[",dechar,"]",sep="")
  splitlist<-strsplit(as.character(x),splitchar)
  ints<-unlist(lapply(splitlist,"[",1))
@@ -7,10 +8,10 @@ decimal.align<-function(x,dechar=".",nint=NA,ndec=NA,pad.left=TRUE) {
   if(is.na(nint)) nint<-max(nchar(ints))
   ints<-sprintf(paste("%",nint,"s",sep=""),ints)
  }
- if(is.na(ndec))
-  ndec<-max(nchar(unlist(splitlist)[seq(2,2*length(x),by=2)]))
+ if(is.na(ndec)) ndec<-max(nchar(unlist(lapply(splitlist,"[",2))))
  decs<-unlist(lapply(splitlist,"[",2))
  decs[is.na(decs)]<-"0"
- decs<-sprintf(paste("%-",ndec,"s",sep=""),decs)
- return(paste(ints,decs,sep="."))
+ decs<-sprintf(paste("%-",ndec,"s",sep=""),
+  decs)
+ return(paste(ints,decs,sep=dechar))
 }
